# Simulating an Ecological Gradient with Multiple Short-Lived Events in a Microfossil Record"

# This script simulates the creation of assemblages across an imaginary core 
# via small time-steps with fixed sed rates and foram density/yr
# using empirically derived KDEs to generate the assemblage, based on
# the foram abundances reported by Sharon et al., 2021, with a wide variety
# of additional sedimentary processes.

# Control Box
set.seed(444)
run_name <- "TSsims_SharonEtAl"
nEvents <- 100     # number of event spikes to simulate
plot <- FALSE

# what original dataset to use?
origDatasetSelection <- "SharonEtAl"
#origDatasetSelection <- "2016"

# NEED TO MODIFY NUMBER OF BREAKS USED IN GRADIENT HISTOGRAM FOR KDE
    # full dataset = 20, for 2016 dataset, use 12
nBreaksGradientHist <- 20

# start from beginning or not??
    # use this if you need to restart a run
setStart <- 1

###################################################################

# Parameters to vary *between* sets

samplingCompleteness_setParamValues <- 1 # c(1, 0.25)
bioturbIntensity_setParamValues <- 0 # c(0, 1)
transitionDurationRatio_setParamValues <- 5 # c(0.001, 0.5, 1, 5)

# background (and thus event) gradient magnitudes
bgGradientValue_setParamValues <- -0.5 # c(-0.5, 0.5, 1)

#######################################################

# Parameters to vary *within* a set
eventSampleWidth_paramValues <- c(
    0.05, 0.1, 0.15, 0.20, 0.3, 0.4,
    seq(from = 0.5, to = 7, by = 0.5)
    )
    
    #0.01, 0.02, 0.03, 0.05, 
    #0.1, 0.12, 0.15, 
    #0.2, 0.25, 0.3, 0.35, 0.4,
    #0.5, 0.6, 0.7, 0.8, 0.9, 
    #1, 1.5, 2, 3, 4, 7, 10
    #)

#################################################################

get_eventGradientChange_paramValues <- function(bgGradientValue){
    if(bgGradientValue == -0.5){
        eventGradientChange_paramValues <- c(
            seq(0, 2.996, by = 0.2)
            )
        
            # ## 0.01, 0.02, 0.03, 0.04, 0.05, 0.07, 0.1, 0.12, 0.15,
            # 0, 0.05, 0.1, 0.15,        
            # 0.14, # effectively 0 DCA1 (when background is -0.5)
            # 0.2, 0.25, 0.3, 0.35, 0.4, 0.45, 0.5 
            # , 0.55, 0.6, 0.65, 0.7   # cannot have event-change beyond 0.5 when background is 0.5
            # ,0.7227      # effectively 2.25 DCA1 (when background is -0.5),
            # ,0.75
            # ## ,0.788        # effectively 2.5 DCA1 (when background is -0.5)
            # )
        }
    if(bgGradientValue == 0.5){
        eventGradientChange_paramValues <- c(
            seq(0, 1.996, by = 0.2)
            )
        
            
            #0, 0.05, 0.1, 0.15,
            #0.14,          # effectively 0 DCA1 (when background is -0.5)
            #0.2, 0.25, 0.3, 0.35, 0.4, 0.45, 0.5 
            # ,0.6, 0.7   # cannot have event-change beyond 0.5 when background is 0.5
            # ,0.7227      # effectively 2.25 DCA1 (when background is -0.5),
            # ,0.75
            ### ,0.788        # effectively 2.5 DCA1 (when background is -0.5)
            #)
        }
    if(bgGradientValue == 1){
        eventGradientChange_paramValues <- c(
            seq(0, 1.496, by = 0.2)
            )
        
            #0, 0.05, 0.1, 0.15,
            #0.14,          # effectively 0 DCA1 (when background is -0.5)
            #0.2, 0.25, 0.3, 0.35, 
            #0.39 
            # ,0.45, 0.5 
            # ,0.6, 0.7   # cannot have event-change beyond 0.5 when background is 0.5
            # ,0.7227      # effectively 2.25 DCA1 (when background is -0.5),
            # ,0.75
            ### ,0.788        # effectively 2.5 DCA1 (when background is -0.5)
            #)
        }
    # DIVIDE THESE BY THE GRADIENT LENGTH (10-25-21)
    gradientLength <- 3.805
    eventGradientChange_paramValues <- eventGradientChange_paramValues/gradientLength
    
    return(eventGradientChange_paramValues)
    }

#####################################################################################
####################################################################################

if(origDatasetSelection == "2016"){
    
    # > summary(gradientOrigDCA)
    #    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
    # -1.5430 -0.7008 -0.2999  0.0000  0.4774  2.3534 
    # > max(gradientOrigDCA) - min(gradientOrigDCA)
    # [1] 3.896397
    
    get_eventGradientChange_paramValues <- function(bgGradientValue){
        
        if(bgGradientValue == -0.5){
            eventGradientChange_paramValues <- c(
                seq(0, 2.85, by = 0.2)
                )
            }
        if(bgGradientValue == 0.5){
            eventGradientChange_paramValues <- c(
                seq(0, 1.85, by = 0.2)
                )
            }
        if(bgGradientValue == 1){
            eventGradientChange_paramValues <- c(
                seq(0, 1.35, by = 0.2)
                )
            }
        # DIVIDE THESE BY THE GRADIENT LENGTH (10-25-21)
        gradientLength <- 3.896397
        eventGradientChange_paramValues <- eventGradientChange_paramValues/gradientLength
        
        return(eventGradientChange_paramValues)
        }
    
    }

#########################################################


# run script
source("batch_scripts/runAllSimulationSets.R")
