# This script calculates the difference maps shown in Figure 7 of the final manuscript,
# illustrating the effect of bioturbation on the detection and magnitude of shifts in
# the paleoenvironmental gradient.

pdfname <- "diff_maps_bioturb_06-25-22.pdf"

# All simulations figured include bioturbation 
# and use a background DCA-1 value of -0.5. 

# Simulation results for 
# (A) 100% sampling comp & transition dur 0.001 times the event duration, 
# (B) 100% sampling comp & transition dur 5 times the event duration, 
# (C) 25% sampling comp & transition dur 0.001 times the event duration, and 
# (D) 25% sampling comp & transition dur 5 times the event duration.  

# make the difference map of (A) to (D) for event detection/accuracy


## LOAD FILES

##############
# NOTE
# users will need to update the date in directories below to date of new simulations
# The generating code adds a dynamic date so simulation runs on different dates don't  
#############

# scenarios with bioturbation
envFileA <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_1_complete__-0.5_bg_1_bioturbInt_0.001_transDurRatio_06-09-22.Rdata"
    
envFileB <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_1_complete__-0.5_bg_1_bioturbInt_5_transDurRatio_06-12-22.Rdata"
    
envFileC <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_0.25_complete__-0.5_bg_1_bioturbInt_0.001_transDurRatio_06-09-22.Rdata"
    
envFileD <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_0.25_complete__-0.5_bg_1_bioturbInt_5_transDurRatio_06-12-22.Rdata"
    
# equivalents without bioturbation
envFileAnb <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_1_complete__-0.5_bg_0_bioturbInt_0.001_transDurRatio_06-09-22.Rdata"
    
envFileBnb <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_1_complete__-0.5_bg_0_bioturbInt_5_transDurRatio_06-11-22.Rdata"
    
envFileCnb <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_0.25_complete__-0.5_bg_0_bioturbInt_0.001_transDurRatio_06-09-22.Rdata"
    
envFileDnb <- "savedEnv/TSsims_SharonEtAL_06-11-22/saved_postSimulations_eventAnalysis_set_0.25_complete__-0.5_bg_0_bioturbInt_5_transDurRatio_06-11-22.Rdata"

#warning(envFile)
load(envFileA) 
propDetectedA <- simSetSummaryList$propEventsDetectedAndWithinOneUnit
load(envFileB) 
propDetectedB <- simSetSummaryList$propEventsDetectedAndWithinOneUnit
load(envFileC) 
propDetectedC <- simSetSummaryList$propEventsDetectedAndWithinOneUnit
load(envFileD) 
propDetectedD <- simSetSummaryList$propEventsDetectedAndWithinOneUnit

#warning(envFile)
load(envFileAnb) 
propDetectedAnb <- simSetSummaryList$propEventsDetectedAndWithinOneUnit
load(envFileBnb) 
propDetectedBnb <- simSetSummaryList$propEventsDetectedAndWithinOneUnit
load(envFileCnb) 
propDetectedCnb <- simSetSummaryList$propEventsDetectedAndWithinOneUnit
load(envFileDnb) 
propDetectedDnb <- simSetSummaryList$propEventsDetectedAndWithinOneUnit


sourceFiles <- list.files(
    path = "R/", 
    full.names = TRUE)
#sourceFiles
for(i in sourceFiles){
    source(i)
    }    


#plotHeatmapComparison(
#    x = eventSampleWidth_paramValues,
#    y = eventGradientChange_paramValues * diff(fullGradientRange),
#    z = propDetectedA
#    )

#plotHeatmapComparison(
#    x = eventSampleWidth_paramValues,
#    y = eventGradientChange_paramValues * diff(fullGradientRange),
#    z = propDetectedB
#    )


pdf(file = pdfname,
    useDingbats = FALSE,
    height = 7, width = 7
    )

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedA - propDetectedAnb) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),
    
    additionalFeatures = {
            contour(
                x = eventSampleWidth_paramValues,
                y = eventGradientChange_paramValues * diff(fullGradientRange),
                z = (propDetectedA - propDetectedAnb) * 100,                
                
                xlim = range(eventSampleWidth_paramValues, 
                    finite = TRUE), 
                ylim = range(eventGradientChange_paramValues * diff(fullGradientRange),
                    finite = TRUE), 
                zlim = c(-100, 100),
                        
                levels = 0, 
                lwd = 1,
                lty = c(1),
                col = "black",
                        
                drawlabels = FALSE, 
                axes = FALSE, 
                frame.plot = FALSE, 
                add = TRUE
                )},

    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    main = c("5A: bg -0.5, Complete, FastTrans\n",
            "Diff Map of Bioturb. - NoBioturb"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedB - propDetectedBnb) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),

    additionalFeatures = {
            contour(
                x = eventSampleWidth_paramValues,
                y = eventGradientChange_paramValues * diff(fullGradientRange),
                z = (propDetectedB - propDetectedBnb) * 100,                
                
                xlim = range(eventSampleWidth_paramValues, 
                    finite = TRUE), 
                ylim = range(eventGradientChange_paramValues * diff(fullGradientRange),
                    finite = TRUE), 
                zlim = c(-100, 100),
                        
                levels = 0, 
                lwd = 1,
                lty = c(1),
                col = "black",
                        
                drawlabels = FALSE, 
                axes = FALSE, 
                frame.plot = FALSE, 
                add = TRUE
                )},
        
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    main = c("5B: bg -0.5, Complete, SlowTrans\n",
            "Diff Map of Bioturb. - NoBioturb"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedC - propDetectedCnb) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),

    additionalFeatures = {
            contour(
                x = eventSampleWidth_paramValues,
                y = eventGradientChange_paramValues * diff(fullGradientRange),
                z = (propDetectedC - propDetectedCnb) * 100,                
                
                xlim = range(eventSampleWidth_paramValues, 
                    finite = TRUE), 
                ylim = range(eventGradientChange_paramValues * diff(fullGradientRange),
                    finite = TRUE), 
                zlim = c(-100, 100),
                        
                levels = 0, 
                lwd = 1,
                lty = c(1),
                col = "black",
                        
                drawlabels = FALSE, 
                axes = FALSE, 
                frame.plot = FALSE, 
                add = TRUE
                )},
        
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    main = c("5C: bg -0.5, Incomp, FastTrans\n",
            "Diff Map of Bioturb. - NoBioturb"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedD - propDetectedDnb) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),
    
    additionalFeatures = {
            contour(
                x = eventSampleWidth_paramValues,
                y = eventGradientChange_paramValues * diff(fullGradientRange),
                z = (propDetectedD - propDetectedDnb) * 100,                
                
                xlim = range(eventSampleWidth_paramValues, 
                    finite = TRUE), 
                ylim = range(eventGradientChange_paramValues * diff(fullGradientRange),
                    finite = TRUE), 
                zlim = c(-100, 100),
                        
                levels = 0, 
                lwd = 1,
                lty = c(1),
                col = "black",
                        
                drawlabels = FALSE, 
                axes = FALSE, 
                frame.plot = FALSE, 
                add = TRUE
                )},
    
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    main = c("5D: bg -0.5, Incomp, SlowTrans\n",
            "Diff Map of Bioturb. - NoBioturb"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

###########################
# comparisons between A, B, C, D
###################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedA - propDetectedB) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),
    
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    #main = plotName,
    main = c("Bioturb. with bg -0.5, Diff Map:\n",
        "A_Comp_RapidTrans - B_Comp_SlowTrans"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedA - propDetectedC) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),
    
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    #main = plotName,
    main = c("Bioturb. with bg -0.5, Diff Map:\n",
        "A_Comp_RapidTrans - C_Incomp_RapidTrans"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedA - propDetectedD) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),
    
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    #main = plotName,
    main = c("Bioturb. with bg -0.5, Diff Map:\n",
        "A_Comp_RapidTrans - D_Incomp_SlowTrans"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

##########################################

plotHeatmapComparison(
    x = eventSampleWidth_paramValues,
    y = eventGradientChange_paramValues * diff(fullGradientRange),
    z = (propDetectedC - propDetectedD) * 100,
    # xlog = TRUE,
    # xlim = c(0.02, 7),
    # ylim = c(0.7, 1.4), # constraining scale to compare patterns at different background values
    xtick = round(eventSampleWidth_paramValues, 2),
    ytick = round(eventGradientChange_paramValues * diff(fullGradientRange), 2),
    
    nlevels = 20,
    zlim = c(-100, 100),
    
    xlab = "Resolution Potential", 
    ylab = "Excursion Magnitude", 
        #,\n Scaled to Max Length of Gradient", 
    
    #main = plotName,
    main = c("Bioturb. with bg -0.5, Diff Map:\n",
        "C_Incomp_RapidTrans - D_Incomp_SlowTrans"),
    
    margins = c(5,6,4,5),
    
    palette = "Temps",
    #palette = "Inferno",
    #additionalFeatures = {grid(col=rgb(1,1,1,0))},
    gradientKeyLabel = paste0(
        "Difference in % of Events Detected &\n",
        "Within One Unit of Sim. Magnitude"
        )
    )  

dev.off()
