# This script was used to analyze the mixing simulation files generated by
# 06_mixingSim_generatedData_06-24-22.R, as described in section 3.4,
# and generate the figures 7 and 8 for the final manuscript.

# these need to be the same filenames and paths as you used in script 06
savedDCAmeasuredFile <- "savedEnv/simMixed_DCA_06-24-22_bg-0.5.Rdata"
savedMixedAbundFile <- "savedEnv/simMixed_abundances_06-24-22_bg-0.5.Rdata"
pdfname <- "savedEnv/abstract_final_figures_06-25-22.pdf"

load(paste0("savedEnv/",
    savedDCAmeasuredFile
    ))

bgGradientValue <- attr(DCA_measured, "bgGradientValue")
foramsPerYear <- attr(DCA_measured, "foramsPerYear") 
nPickedSpecimens <- attr(DCA_measured, "nPickedSpecimens") 
ntrials <- attr(DCA_measured, "ntrials")
eventMagnitude_set <- attr(DCA_measured, "eventMagnitude_set")
propEventSampleOverlap_set <- attr(DCA_measured, "propEventSampleOverlap_set")

sourceFiles <- list.files( path = "R/", 
    full.names = TRUE)
#sourceFiles
for(i in sourceFiles){
    source(i)
    }  

paramCombinations <- expand.grid(eventMagnitude_set, 
    propEventSampleOverlap_set)
colnames(paramCombinations) <- c(
    "eventMagnitude", 
    "propEventSampleOverlap")

makeProperTable <- function(fill_variable){
    makeSimSetTable(fill_variable = fill_variable,
        x_variable_from_table = paramCombinations$eventMagnitude, 
        y_variable_from_table = paramCombinations$propEventSampleOverlap,
        x_variable = eventMagnitude_set,
        y_variable = propEventSampleOverlap_set,
        x_variable_label = "eventMagnitude_",
        y_variable_label = "propEventSampleOverlap_"
        )
    }
    

# Plots of DCA values Observed in Simulations at Different Magnitudes & Event-Sample Overlap

medianDCA <- lapply(DCA_measured, median)
minDCA <- lapply(DCA_measured, min)
maxDCA <- lapply(DCA_measured, max)

medianDCA <- makeProperTable(fill_variable = medianDCA)
minDCA <- makeProperTable(minDCA)
maxDCA <- makeProperTable(maxDCA)

# make pdf for all figures
pdf(file = pdfname,
    useDingbats = FALSE,
    height = 7, width = 7
    )

## Median DCA

plotHeatmapComparison(
    x = eventMagnitude_set,
    y = propEventSampleOverlap_set,
    z = medianDCA,
    zlim=c(min(minDCA), max(maxDCA)),    
    #xtick = eventMagnitude_set,
    #ytick = propEventSampleOverlap_set,
    palette = "Zissou.1",
    main = paste0(
        "Median Observed DCA Value", 
        "\n Across Simulated Samples",
        "\nAt Various Magnitudes & Event %"
        ),
    xlab = "True Magnitude of Event",
    ylab = "Proportion of Sample Drawn\n from Event Assemblages",
    gradientKeyLabel = "Median DCA Value Observed"
    )


## Maximum DCA

plotHeatmapComparison(
    x = eventMagnitude_set,
    y = propEventSampleOverlap_set,
    z = maxDCA,
    zlim=c(min(minDCA), max(maxDCA)),
    #xtick = eventMagnitude_set,
    #ytick = propEventSampleOverlap_set,
    palette = "Zissou.1",
    main = paste0(
        "Maximum Observed DCA Value", 
        "\n Across Simulated Samples",
        "\nAt Various Magnitudes & Event %"
        ),
    xlab = "True Magnitude of Event",
    ylab = "Proportion of Sample Drawn\n from Event Assemblages",
    gradientKeyLabel = "Max DCA Value Observed"
    )

## Minimum DCA

plotHeatmapComparison(
    x = eventMagnitude_set,
    y = propEventSampleOverlap_set,
    z = minDCA,
    zlim=c(min(minDCA), max(maxDCA)),
    #xtick = eventMagnitude_set,
    #ytick = propEventSampleOverlap_set,
    palette = "Zissou.1",
    main = paste0(
        "Minimum Observed DCA Value", 
        "\n Across Simulated Samples",
        "\nAt Various Magnitudes & Event %"
        ),
    xlab = "True Magnitude of Event",
    ylab = "Proportion of Sample Drawn\n from Event Assemblages",
    gradientKeyLabel = "Min DCA Value Observed"
    )


# The Probability of Recognizing an Event Occurred, 
    # Given Observing Some DCA Value, 
    # in Simulations with Varying Magnitude and How Much Sample Captured the Event

# DCA obs : What is the likely chance of DCA spike of X?

plot_propDCAwithin <- function(DCA_obs){
    # identify upper and lower bounds on bgGradientValue
    closestMagnitude_to_obs <- abs(eventMagnitude_set - DCA_obs)
    closestMagnitude_to_obs <- which(closestMagnitude_to_obs == min(closestMagnitude_to_obs))
    closestMagnitude_to_obs <- eventMagnitude_set[closestMagnitude_to_obs]
    
    # get observed DCA values
    obs_DCAvalues <- DCA_measured[[
        which(paramCombinations$eventMagnitude == closestMagnitude_to_obs &
            paramCombinations$propEventSampleOverlap ==1)]]
    bounds_obsDCA <- quantile(obs_DCAvalues, c(0.025, 0.975))
    # modify the bounds so they are around the observed DCA value
    bounds_obsDCA <- bounds_obsDCA - closestMagnitude_to_obs + DCA_obs
    
    # create bounds of 1 unit around DCA value
    #bounds_obsDCA <- c(-1,1) - closestMagnitude_to_obs + DCA_obs
    
    ######################################
    # measure how many
    
    propDCAwithin <- lapply(DCA_measured, function(x)
        sum(x > bounds_obsDCA[[1]] & x < bounds_obsDCA[[2]]
            )/length(x)
        )
    
    propDCAwithin <- makeProperTable(fill_variable = propDCAwithin)
                                                       
    plotHeatmapComparison(
        x = eventMagnitude_set,
        y = propEventSampleOverlap_set,
        z = propDCAwithin * 100,
        additionalFeatures = {
            abline(v = DCA_obs, lwd = 3, col = "green")
            text(x = DCA_obs-0.08, y = 0.25, 
                labels = "Obs. DCA Value",
                col = "green", srt = 90)
            },
        #xtick = eventMagnitude_set,
        #ytick = propEventSampleOverlap_set,
        main = paste0(
            "Probability of Observing DCA Value of ", DCA_obs, 
            "\n Across Simulated Samples",
            "\nAt Various Magnitudes & Event %"),
        xlab = "True Magnitude of Event",
        ylab = "Proportion of Sample Drawn\n from Event Assemblages",
        gradientKeyLabel = paste0(
            "% of Simulated DCA values within\n",
            "95% Envelope of Obs. (", 
            round(bounds_obsDCA[1], 2), " - ", 
            round(bounds_obsDCA[2], 2), ")")
        )

    }

# For plots below, the green vertical line is at the fixed, 
    #observed value being evaluated. 
# This is a fixed value: the question is, 
    # if we see an event that is 0.4 on the DCA axis, 
    # how often might we expect to have gotten that 
    # if the event was actually 1.4 magnitude? 
# How much shorter would the event have to be relative to our sample width
    # in order for it to reflect an event with 2.4 magnitude?

# If you observe a DCA excursion of 0

plot_propDCAwithin(DCA_obs = 0)

# If you observe a DCA excursion of 1

plot_propDCAwithin(DCA_obs = 1)

# If you observe a DCA excursion of 2

plot_propDCAwithin(DCA_obs = 2)

dev.off()