# 12_make_sim_abund_distributions_for_specific_DCA_02-10-23.R
    # This R script creates the PDF of sample-specifc figures that we have put 
    # as a second set of supplementary materials, S2.

setwd("~/workspace/simulating_fossil_indices/")

# number of assemblage samples to draw for a gradient value
nSamples <- 100

# how many forams are drawn for each assemblage sample?
nForams <- 300
# OR use original sample size instead?
useOrigSampleSize <- FALSE

# Loading the Empirical Ecological Dataset For 
    # Generating Simulated Species Distributions via KDEs
origAbundDataTable <- read.table(
    "data/foram_abundances_forSimulations.txt",
    header = TRUE, row.names = 1)
# remove first four columns of data that aren't abundances
origAbundData <- origAbundDataTable[, -(1:4)] 
# get DCA1
gradientOrigDCA <- origAbundDataTable$DCA1
# Calculate full gradient range
fullGradientRange <- c(min(gradientOrigDCA), max(gradientOrigDCA))
nSpecies <- ncol(origAbundData)

# verify that original DCA1 in data file
    # matches what we get from
    # running a new DCA analysis
origRelAbund <- t(apply(origAbundData, 1, function(x) x/sum(x)))
dcaOut <- vegan::decorana(origRelAbund)
outputDCA1 <- vegan::scores(dcaOut)[ , 1]
# do they plot on a 1-1 line? yes
#plot(gradientOrigDCA, outputDCA1); abline(0,1)
# sum of error?
sqrt(sum((gradientOrigDCA - outputDCA1)^2))
# tiny - 0.015
# biggest shift? --> 0.0101
max(gradientOrigDCA - outputDCA1)

# get fixed species names
fixedSpeciesNames <- read.csv( 
    "data/species_name_revisions_for_plotting_01-30-23.csv")
fixedSpeciesNames <- fixedSpeciesNames[order(fixedSpeciesNames$id),]

### 
# load functions
sourceFiles <- list.files(
    path = "R/", 
    full.names = TRUE)
#sourceFiles
for(i in sourceFiles){
    source(i)
    }   

# Fit rescaled kernal density estimates for each species along axis DCA-1.
kdeRescaled <- getSpeciesSpecificRescaledKDE(
    gradientOrigDCA = gradientOrigDCA, 
    origAbundData = origAbundData)

# Make a function for sampling species presence 
    # at a point along the DCA gradient  
    # based solely on presence and absence
sampleSpeciesGradient <- getProbOccViaPresAbs(
    gradientOrigDCA = gradientOrigDCA, 
    origAbundData = origAbundData
    )

##############

#gradientValuesSet <- sample(size = 100, unique(gradientOrigDCA))
#gradientValuesSet <- c(min(gradientOrigDCA), 
    # max(gradientOrigDCA), gradientValuesSet)
#gradientValuesSet <- sort(unique(gradientValuesSet))
#gradientValuesSet
#plot(diff(gradientValuesSet))

gradientValuesSet <- gradientOrigDCA

sampAbundancesList <- list()
sampAbundancesMax <- numeric()

for(i in 1:length(gradientValuesSet)){
    
    if(useOrigSampleSize){
        nForams <- sum(origAbundData[i,])
        }
    
    sampAbundances <- getTimestepAbundances(
        kdeRescaled = kdeRescaled, 
        sampleSpeciesGradient = sampleSpeciesGradient, 
        gradientValues = rep(gradientValuesSet[i], nSamples), 
        foramsPerYear = nForams
        )

    # max relative abundance
    sampAbundancesMax[i] <- max(sampAbundances/nForams)
    
    colnames(sampAbundances) <- fixedSpeciesNames$print_name
    sampAbundancesList[[i]] <- sampAbundances
    }


# make all this as a PDF
pdf(
    "comparing_simulated_assemblages_to_empirical_02-10-23.pdf",
    width = 11, height = 6
    )

# what is max relative abundance
    # across all species, sites
# original data
origMaxRA <- max(origRelAbund)
# simulated data
simMaxRA <- max(sampAbundancesMax)
maxRA <- max(c(origMaxRA, simMaxRA))

par(mar = c(13,5,3,1))

for(i in order(gradientValuesSet)){

    sampAbundances <- sampAbundancesList[[i]]

    if(useOrigSampleSize){
        nForams <- sum(origAbundData[i,])
        }
    
    #colnames(sampAbundances) <- c(letters,paste0(letters,letters))[1:48]
        
    maxAbund <- max(c(
        max(origAbundData[i,]/sum(origAbundData[i,])), 
        max(sampAbundances/nForams)
        ))
    
    # order based on original samples
    #abundOrder <- order(-apply(sampAbundances,2,max)
    abundOrder <- order(-as.numeric(origAbundData[i,]))    
    
    boxplot(sampAbundances[ , abundOrder
            ] / nForams, 
        #ylab = paste0("Abundances across ", nSamples,
        #    " samples, each ", nForams,
        #    " individuals sampled")
        ylab = paste0("Rel. Abundances across ", nSamples,
            " samples,\n each ", nForams,
            " individuals sampled"),
        main = paste0(
            rownames(origAbundDataTable)[i],
            ", DCA1 = ", gradientValuesSet[i],
            ", ", if(useOrigSampleSize){
                paste0("Used Original Sample Size of ", nForams)
            }else{
                paste0("Used Constant Sample Size of ", nForams)   
                }
            ),
        ylim = c(0, maxAbund), las = 2 
        )
    
    points( 1:ncol(sampAbundances), 
        origAbundData[i, abundOrder
            ] / sum(origAbundData[i,]),
        col = "red", pch = 13
        )

    abline(
        v = (which(origAbundData[i,abundOrder] == 0)[1]) + 0.5 , 
        lwd = 2, col = 2    
        )

    }

dev.off()

